<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ko" sourcelanguage="en">
<context>
    <name>ArtisticSolidColor</name>
    <message>
        <source>Horiz Offset</source>
        <translation>수평 상쇄</translation>
    </message>
    <message>
        <source>Vert Offset</source>
        <translation>수직 상쇄</translation>
    </message>
    <message>
        <source>Noise</source>
        <translation>소음</translation>
    </message>
    <message>
        <source>Irregular</source>
        <translation>불규칙</translation>
    </message>
</context>
<context>
    <name>FlowLineStrokeStyle</name>
    <message>
        <source>Density</source>
        <translation>밀도</translation>
    </message>
    <message>
        <source>Extension</source>
        <translation>확장</translation>
    </message>
    <message>
        <source>Width Scale</source>
        <translation>폭 척도</translation>
    </message>
    <message>
        <source>Straighten Ends</source>
        <translation>끝을 똑바로</translation>
    </message>
    <message>
        <source>Flow Line</source>
        <translation>흐름라인</translation>
    </message>
</context>
<context>
    <name>MovingSolidColor</name>
    <message>
        <source>Horiz Offset</source>
        <translation>수평 상쇄</translation>
    </message>
    <message>
        <source>Vert Offset</source>
        <translation>수직 상쇄</translation>
    </message>
    <message>
        <source>Offset</source>
        <translation>상쇄</translation>
    </message>
</context>
<context>
    <name>OutlineViewerStyle</name>
    <message>
        <source>Control Point</source>
        <translation>제어점</translation>
    </message>
    <message>
        <source>Center Line</source>
        <translation>중심선</translation>
    </message>
    <message>
        <source>Outline Mode</source>
        <translation>윤곽모드</translation>
    </message>
    <message>
        <source>Distance</source>
        <translation>거리</translation>
    </message>
    <message>
        <source>distance</source>
        <translation>거리</translation>
    </message>
    <message>
        <source>OutlineViewer(OnlyDebug)</source>
        <translation>윤곽선 보기(전체오류수정)</translation>
    </message>
</context>
<context>
    <name>ShadowStyle</name>
    <message>
        <source>Angle</source>
        <translation>각도</translation>
    </message>
    <message>
        <source>Density</source>
        <translation>밀도</translation>
    </message>
    <message>
        <source>Length</source>
        <translation>길이</translation>
    </message>
    <message>
        <source>Hatched Shading</source>
        <translation>배선음영</translation>
    </message>
</context>
<context>
    <name>ShadowStyle2</name>
    <message>
        <source>Angle</source>
        <translation>각도</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>크기</translation>
    </message>
    <message>
        <source>Plain Shadow</source>
        <translation>그림자(표준)</translation>
    </message>
</context>
<context>
    <name>TAirbrushRasterStyle</name>
    <message>
        <source>Airbrush</source>
        <translation>에어브러시</translation>
    </message>
    <message>
        <source>Blur value</source>
        <translation>흐릿한 값</translation>
    </message>
</context>
<context>
    <name>TBiColorStrokeStyle</name>
    <message>
        <source>Shade</source>
        <translation>음영</translation>
    </message>
</context>
<context>
    <name>TBlendRasterStyle</name>
    <message>
        <source>Blend</source>
        <translation>혼합</translation>
    </message>
</context>
<context>
    <name>TBlendStrokeStyle2</name>
    <message>
        <source>Border Fade</source>
        <translation>경계선 흐림</translation>
    </message>
    <message>
        <source>Fade In</source>
        <translation>페이드 인</translation>
    </message>
    <message>
        <source>Fade Out</source>
        <translation>페이드 아웃</translation>
    </message>
    <message>
        <source>Fade</source>
        <translation>페이드</translation>
    </message>
</context>
<context>
    <name>TBraidStrokeStyle</name>
    <message>
        <source>Twirl</source>
        <translation>회전</translation>
    </message>
    <message>
        <source>Plait</source>
        <translation>플레이트</translation>
    </message>
</context>
<context>
    <name>TBubbleStrokeStyle</name>
    <message>
        <source>Bubbles</source>
        <translation>거품</translation>
    </message>
</context>
<context>
    <name>TChainStrokeStyle</name>
    <message>
        <source>Chain</source>
        <translation>체인</translation>
    </message>
</context>
<context>
    <name>TChalkFillStyle</name>
    <message>
        <source>Density</source>
        <translation>밀도</translation>
    </message>
    <message>
        <source>Dot Size</source>
        <translation>점 크기</translation>
    </message>
    <message>
        <source>Chalk</source>
        <translation>분필</translation>
    </message>
</context>
<context>
    <name>TChalkStrokeStyle2</name>
    <message>
        <source>Border Fade</source>
        <translation>경계선 흐림</translation>
    </message>
    <message>
        <source>Density</source>
        <translation>밀도</translation>
    </message>
    <message>
        <source>Fade In</source>
        <translation>페이드 인</translation>
    </message>
    <message>
        <source>Fade Out</source>
        <translation>페이드 아웃</translation>
    </message>
    <message>
        <source>Noise</source>
        <translation>소음</translation>
    </message>
    <message>
        <source>Chalk</source>
        <translation>분필</translation>
    </message>
</context>
<context>
    <name>TCheckedFillStyle</name>
    <message>
        <source>Horiz Dist</source>
        <translation>수평거리</translation>
    </message>
    <message>
        <source>Horiz Angle</source>
        <translation>수평각도</translation>
    </message>
    <message>
        <source>Vert Dist</source>
        <translation>수직거리</translation>
    </message>
    <message>
        <source>Vert Angle</source>
        <translation>수직각도</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>굵기</translation>
    </message>
    <message>
        <source>Square</source>
        <translation>사각무늬</translation>
    </message>
</context>
<context>
    <name>TChessFillStyle</name>
    <message>
        <source>Horiz Size</source>
        <translation>수평크기</translation>
    </message>
    <message>
        <source>Vert Size</source>
        <translation>수직크기</translation>
    </message>
    <message>
        <source>Angle</source>
        <translation>각도</translation>
    </message>
    <message>
        <source>Chessboard</source>
        <translation>체스보드</translation>
    </message>
</context>
<context>
    <name>TCircleStripeFillStyle</name>
    <message>
        <source>X Position</source>
        <translation>X 이동</translation>
    </message>
    <message>
        <source>Y Position</source>
        <translation>수직위치</translation>
    </message>
    <message>
        <source>Distance</source>
        <translation>거리</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>굵기</translation>
    </message>
    <message>
        <source>Concentric</source>
        <translation>동심원</translation>
    </message>
</context>
<context>
    <name>TCrystallizeStrokeStyle</name>
    <message>
        <source>Crease</source>
        <translation>주름</translation>
    </message>
    <message>
        <source>Opacity</source>
        <translation>불투명도</translation>
    </message>
    <message>
        <source>Tulle</source>
        <translation>튤</translation>
    </message>
</context>
<context>
    <name>TDottedFillStyle</name>
    <message>
        <source>Dot Size</source>
        <translation>점 크기</translation>
    </message>
    <message>
        <source>Dot Distance</source>
        <translation>점 거리</translation>
    </message>
    <message>
        <source>Polka Dots</source>
        <translation>물방울 무늬</translation>
    </message>
</context>
<context>
    <name>TDottedLineStrokeStyle</name>
    <message>
        <source>Fade In</source>
        <translation>페이드 인</translation>
    </message>
    <message>
        <source>Dash</source>
        <translation>선 부분</translation>
    </message>
    <message>
        <source>Fade Out</source>
        <translation>페이드 아웃</translation>
    </message>
    <message>
        <source>Gap</source>
        <translation>간격</translation>
    </message>
    <message>
        <source>Vanishing</source>
        <translation>소실</translation>
    </message>
</context>
<context>
    <name>TDualColorStrokeStyle2</name>
    <message>
        <source>Distance</source>
        <translation>거리</translation>
    </message>
    <message>
        <source>Striped</source>
        <translation>줄무늬</translation>
    </message>
</context>
<context>
    <name>TFriezeStrokeStyle2</name>
    <message>
        <source>Twirl</source>
        <translation>회전</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>굵기</translation>
    </message>
    <message>
        <source>Curl</source>
        <translation>컬</translation>
    </message>
</context>
<context>
    <name>TFurStrokeStyle</name>
    <message>
        <source>Angle</source>
        <translation>각도</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>크기</translation>
    </message>
    <message>
        <source>Herringbone</source>
        <translation>헤링본</translation>
    </message>
</context>
<context>
    <name>TGraphicPenStrokeStyle</name>
    <message>
        <source>Density</source>
        <translation>밀도</translation>
    </message>
    <message>
        <source>Dashes</source>
        <translation>대시</translation>
    </message>
</context>
<context>
    <name>TLinGradFillStyle</name>
    <message>
        <source>Angle</source>
        <translation>각도</translation>
    </message>
    <message>
        <source>X Position</source>
        <translation>X 이동</translation>
    </message>
    <message>
        <source>Y Position</source>
        <translation>수직위치</translation>
    </message>
    <message>
        <source>Smoothness</source>
        <translation>평활도</translation>
    </message>
    <message>
        <source>Linear Gradient</source>
        <translation>선형 글라디언트</translation>
    </message>
</context>
<context>
    <name>TLongBlendStrokeStyle2</name>
    <message>
        <source>Distance</source>
        <translation>거리</translation>
    </message>
    <message>
        <source>Watercolor</source>
        <translation>수채화</translation>
    </message>
</context>
<context>
    <name>TMatrioskaStrokeStyle</name>
    <message>
        <source>Stripes</source>
        <translation>줄무늬</translation>
    </message>
    <message>
        <source>Toothpaste</source>
        <translation>치약</translation>
    </message>
</context>
<context>
    <name>TMosaicFillStyle</name>
    <message>
        <source>Size</source>
        <translation>크기</translation>
    </message>
    <message>
        <source>Distortion</source>
        <translation>왜곡</translation>
    </message>
    <message>
        <source>Min Thick</source>
        <translation>최소 두께</translation>
    </message>
    <message>
        <source>Max Thick</source>
        <translation>최대 두께</translation>
    </message>
    <message>
        <source>Stained Glass</source>
        <translation>스테인드 글라스</translation>
    </message>
</context>
<context>
    <name>TMultiLineStrokeStyle2</name>
    <message>
        <source>Density</source>
        <translation>밀도</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>크기</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>굵기</translation>
    </message>
    <message>
        <source>Noise</source>
        <translation>소음</translation>
    </message>
    <message>
        <source>Gouache</source>
        <translation>수채화법</translation>
    </message>
</context>
<context>
    <name>TNoColorRasterStyle</name>
    <message>
        <source>Markup</source>
        <translation>마크업</translation>
    </message>
</context>
<context>
    <name>TNormal2StrokeStyle</name>
    <message>
        <source>Light X Pos</source>
        <translation>빛의 수평위치</translation>
    </message>
    <message>
        <source>Light Y Pos</source>
        <translation>빛의 수직위치</translation>
    </message>
    <message>
        <source>Shininess</source>
        <translation>광택</translation>
    </message>
    <message>
        <source>Plastic</source>
        <translation>플라스틱</translation>
    </message>
    <message>
        <source>Bump</source>
        <translation>범프</translation>
    </message>
</context>
<context>
    <name>TPatchFillStyle</name>
    <message>
        <source>Size</source>
        <translation>크기</translation>
    </message>
    <message>
        <source>Distortion</source>
        <translation>왜곡</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>굵기</translation>
    </message>
    <message>
        <source>Beehive</source>
        <translation>벌집모양</translation>
    </message>
</context>
<context>
    <name>TPointShadowFillStyle</name>
    <message>
        <source>Angle</source>
        <translation>각도</translation>
    </message>
    <message>
        <source>Density</source>
        <translation>밀도</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>크기</translation>
    </message>
    <message>
        <source>Point Size</source>
        <translation>점 크기</translation>
    </message>
    <message>
        <source>Sponge Shading</source>
        <translation>스펀지 셰이딩</translation>
    </message>
</context>
<context>
    <name>TRadGradFillStyle</name>
    <message>
        <source>X Position</source>
        <translation>X 이동</translation>
    </message>
    <message>
        <source>Y Position</source>
        <translation>수직위치</translation>
    </message>
    <message>
        <source>Radius</source>
        <translation>반지름</translation>
    </message>
    <message>
        <source>Smoothness</source>
        <translation>평활도</translation>
    </message>
    <message>
        <source>Radial Gradient</source>
        <translation>원형 그라디언트</translation>
    </message>
</context>
<context>
    <name>TRopeStrokeStyle</name>
    <message>
        <source>Tilt</source>
        <translation>기울기</translation>
    </message>
    <message>
        <source>Rope</source>
        <translation>로프</translation>
    </message>
</context>
<context>
    <name>TRubberFillStyle</name>
    <message>
        <source>Intensity</source>
        <translation>강도</translation>
    </message>
    <message>
        <source>Blob</source>
        <translation>작은 점</translation>
    </message>
</context>
<context>
    <name>TSawToothStrokeStyle</name>
    <message>
        <source>Distance</source>
        <translation>거리</translation>
    </message>
    <message>
        <source>Jagged</source>
        <translation>톱니모양</translation>
    </message>
</context>
<context>
    <name>TSinStrokeStyle</name>
    <message>
        <source>Frequency</source>
        <translation>주파수</translation>
    </message>
    <message>
        <source>Wave</source>
        <translation>파동</translation>
    </message>
</context>
<context>
    <name>TSketchStrokeStyle</name>
    <message>
        <source>Density</source>
        <translation>밀도</translation>
    </message>
    <message>
        <source>Fuzz</source>
        <translation>퍼즈</translation>
    </message>
</context>
<context>
    <name>TSprayStrokeStyle</name>
    <message>
        <source>Border Fade</source>
        <translation>경계선 흐림</translation>
    </message>
    <message>
        <source>Density</source>
        <translation>밀도</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>크기</translation>
    </message>
    <message>
        <source>Circlets</source>
        <translation>작은 원</translation>
    </message>
</context>
<context>
    <name>TStripeFillStyle</name>
    <message>
        <source>Distance</source>
        <translation>거리</translation>
    </message>
    <message>
        <source>Angle</source>
        <translation>각도</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>굵기</translation>
    </message>
    <message>
        <source>Banded</source>
        <translation>줄무늬</translation>
    </message>
</context>
<context>
    <name>TTissueStrokeStyle</name>
    <message>
        <source>Density</source>
        <translation>밀도</translation>
    </message>
    <message>
        <source>Border Size</source>
        <translation>경계 크기</translation>
    </message>
    <message>
        <source>Gauze</source>
        <translation>그물무늬</translation>
    </message>
</context>
<context>
    <name>TTwirlStrokeStyle</name>
    <message>
        <source>Twirl</source>
        <translation>회전</translation>
    </message>
    <message>
        <source>Shade</source>
        <translation>음영</translation>
    </message>
    <message>
        <source>Ribbon</source>
        <translation>리본</translation>
    </message>
</context>
<context>
    <name>TZigzTSinStrokeStyleagStrokeStyle</name>
    <message>
        <source>Thickness</source>
        <translation>굵기</translation>
    </message>
</context>
<context>
    <name>TZigzagStrokeStyle</name>
    <message>
        <source>Min Distance</source>
        <translation>최소 거리</translation>
    </message>
    <message>
        <source>Max Distance</source>
        <translation>최대 거리</translation>
    </message>
    <message>
        <source>Min Angle</source>
        <translation>최소 각도</translation>
    </message>
    <message>
        <source>Max Angle</source>
        <translation>최대 각도</translation>
    </message>
    <message>
        <source>Thickness</source>
        <translation>굵기</translation>
    </message>
    <message>
        <source>Zigzag</source>
        <translation>지그재그</translation>
    </message>
</context>
</TS>
